@@ -4,6 +4,7 @@ mod test;
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 use std::process::exit;
+use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::{Arc, LazyLock, RwLock};
 
 use tokio::sync::Mutex;
@@ -26,10 +27,20 @@ use crate::{
     BackendInitInfo, ast, complete, document_link, fileapi, filewatcher, hover, jump, quick_fix,
     rename, scansubs, semantic_token, utils,
 };
-use std::sync::atomic::{AtomicBool, Ordering};
 pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Uri, String>>>> =
     LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
 
+pub async fn get_or_update_buffer_context<P: AsRef<Path>>(path: P) -> std::io::Result<String> {
+    let uri = lsp_types::Uri::from_file_path(&path).unwrap();
+    let mut buffer_cache = BUFFERS_CACHE.lock().await;
+    if let Some(context) = buffer_cache.get(&uri) {
+        return Ok(context.clone());
+    }
+    let context = tokio::fs::read_to_string(&path).await?;
+    buffer_cache.insert(uri, context.clone());
+    Ok(context)
+}
+
 static CLIENT_CAPABILITIES: RwLock<Option<TextDocumentClientCapabilities>> = RwLock::new(None);
 static ENABLE_SNIPPET: AtomicBool = AtomicBool::new(false);
 fn set_client_text_document(text_document: Option<TextDocumentClientCapabilities>) {
